@@ -16,13 +16,13 @@ def delete(dirname):
     #On vire la data  du storage
     if(common.isUnlocked(dirname)):
       mp=common.getMountPoint(dirname)
-      log.warning("Your content was previously unlocked at "+ mp +" you have to delete it by yourself")
-      try:
-       common.remove_dir(static.tibis_keys_location+"/"+dirname)
-      except:
-       log.warning("Keys are already gone")
+      log.warning("Your content was previously unlocked at "+ str(mp) +" you have to delete it by yourself")
+    try:
+      common.remove_dir(static.tibis_keys_location+"/"+dirname)
       common.deleteSQLEntry(dirname)
-      log.warning("Entry and keys removed")
+    except:
+     log.warning("Keys are already gone")
+     log.warning("Entry and keys removed")
    else:
     log.success("Leaves the things as it ...")     
 
