@@ -1,7 +1,7 @@
 from pathlib import Path
 
-version  = '1.0.5'
-codename = "Ibis is born"
+version  = '1.2.0'
+codename = "Ibis is optimized"
 
 tibis_config_file="config.yml"
 tibis_config_location=str(Path.home())+"/.config/tibis/"
@@ -27,5 +27,5 @@ tibis_empty_dir="/tmp/tempate_tibis_empty_dir"
 tibis_storage_path="/tmp/storage"
 tibis_tmp_dir="/tmp/tibis_tmp"
 
-default_config={'storage_path':tibis_storage_path,'keys_location':tibis_keys_location,'pgp_infos':{'email':'tibis@localhost.org','comment':'Tibis Key','name':'Tibis'}}
+default_config={'storage_path':tibis_storage_path,'keys_location':tibis_keys_location,'pgp_infos':{'email':'tibis@localhost.org','comment':'Tibis Key','name':'Tibis'},'check_integrity':True,'encrypting':False}
 
